types

package
v0.2.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 5, 2023 License: Apache-2.0 Imports: 4 Imported by: 1

Documentation

Index

Constants

const (
	// RoutingStrategy is the type name use to define a RoutingStrategy
	RoutingStrategy = "ROUTING_STRATEGY"
	// FanIn is the type name use to define a FAN_IN
	FanIn = "FAN_IN"
)

Variables

This section is empty.

Functions

func FanInByName

func FanInByName(name string) (fiber.FanIn, error)

FanInByName identifies a fan in type that matches the type name specified and returns an instance of that type

func InstallType

func InstallType(key string, objectOfType interface{}) error

InstallType updates the type map with new sub-types

func StrategyByName

func StrategyByName(name string) (fiber.RoutingStrategy, error)

StrategyByName identifies a routing strategy type that matches the type name specified and returns an instance of that type

Types

type Category

type Category string

Category is an alias for a string

Jump to