Documentation
¶
Index ¶
Constants ¶
const ( // RoutingStrategy is the type name use to define a RoutingStrategy RoutingStrategy = "ROUTING_STRATEGY" // FanIn is the type name use to define a FAN_IN FanIn = "FAN_IN" )
Variables ¶
This section is empty.
Functions ¶
func FanInByName ¶
FanInByName identifies a fan in type that matches the type name specified and returns an instance of that type
func InstallType ¶
InstallType updates the type map with new sub-types
func StrategyByName ¶
func StrategyByName(name string) (fiber.RoutingStrategy, error)
StrategyByName identifies a routing strategy type that matches the type name specified and returns an instance of that type
Types ¶
Click to show internal directories.
Click to hide internal directories.